# src/ecommerce_toolkit/providers/shopify.py
import requests
from typing import List, Dict
from .base import EcommerceProvider
from ..models.product import Product

class ShopifyProvider(EcommerceProvider):
    def __init__(self, shop_url: str, storefront_token: str):
        self.shop_url = shop_url
        self.storefront_url = f"https://{shop_url}/api/2024-01/graphql.json"
        self.headers = {
            "X-Shopify-Storefront-Access-Token": storefront_token,
            "Content-Type": "application/json"
        }
    
    def _execute_query(self, query: str, variables: Dict = None) -> Dict:
        """Execute a GraphQL query against the Storefront API"""
        response = requests.post(
            self.storefront_url,
            headers=self.headers,
            json={
                "query": query,
                "variables": variables or {}
            }
        )
        response.raise_for_status()
        return response.json()
    
    def get_products(self, first: int = 50) -> List[Product]:
        query = """
        query GetProducts($first: Int!) {
          products(first: $first) {
            edges {
              node {
                id
                title
                description
                priceRange {
                  minVariantPrice {
                    amount
                  }
                }
                totalInventory
              }
            }
          }
        }
        """
        
        result = self._execute_query(query, {"first": first})
        products = result["data"]["products"]["edges"]
        
        return [
            Product(
                id=p["node"]["id"].split("/")[-1],
                name=p["node"]["title"],
                price=float(p["node"]["priceRange"]["minVariantPrice"]["amount"]),
                stock=p["node"]["totalInventory"],
                description=p["node"].get("description", "")
            )
            for p in products
        ]
    
    def get_product(self, product_id: str) -> Product:
        query = """
        query GetProduct($id: ID!) {
          product(id: $id) {
            id
            title
            description
            priceRange {
              minVariantPrice {
                amount
              }
            }
            totalInventory
          }
        }
        """
        
        # Format product ID for GraphQL
        gql_id = f"gid://shopify/Product/{product_id}"
        
        result = self._execute_query(query, {"id": gql_id})
        p = result["data"]["product"]
        
        return Product(
            id=p["id"].split("/")[-1],
            name=p["title"],
            price=float(p["priceRange"]["minVariantPrice"]["amount"]),
            stock=p["totalInventory"],
            description=p.get("description", "")
        )
    
    def search_products(self, query: str) -> List[Product]:
        gql_query = """
        query SearchProducts($query: String!) {
          products(query: $query, first: 20) {
            edges {
              node {
                id
                title
                description
                priceRange {
                  minVariantPrice {
                    amount
                  }
                }
                totalInventory
              }
            }
          }
        }
        """
        
        result = self._execute_query(gql_query, {"query": query})
        products = result["data"]["products"]["edges"]
        
        return [
            Product(
                id=p["node"]["id"].split("/")[-1],
                name=p["node"]["title"],
                price=float(p["node"]["priceRange"]["minVariantPrice"]["amount"]),
                stock=p["node"]["totalInventory"],
                description=p["node"].get("description", "")
            )
            for p in products
        ]
    
    def predictive_search(self, query: str) -> Dict:
        """
        Perform predictive search using Shopify's Predictive Search API
        Returns raw results including products, collections, and articles
        """
        search_url = f"https://{self.shop_url}/search/suggest.json"
        response = requests.get(
            search_url,
            params={
                "q": query,
                "resources[type]": "product,collection,article",
                "resources[limit]": 10,
                "resources[options][unavailable_products]": "show",
                "resources[options][fields]": "title,product_type,variants.title"
            }
        )
        response.raise_for_status()
        return response.json()

# Update config.py to use Storefront token
class StoreConfig:
    def __init__(self):
        load_dotenv()
        self.store_url = os.getenv("STORE_URL")
        self.store_type = self._detect_store_type()
        
        # Shopify specific
        self.shopify_storefront_token = os.getenv("SHOPIFY_STOREFRONT_TOKEN")  # Updated
        
        # WooCommerce specific
        self.woo_key = os.getenv("WOO_CONSUMER_KEY")
        self.woo_secret = os.getenv("WOO_CONSUMER_SECRET")
        
        if not self.store_url:
            raise ValueError("STORE_URL environment variable is required")

# Update toolkit.py to include predictive search
class EcommerceToolkit:
    # ... (previous methods remain the same)
    
    def predictive_search(self, query: str) -> Dict:
        """
        Perform predictive search if the provider supports it
        """
        if hasattr(self.provider, 'predictive_search'):
            return self.provider.predictive_search(query)
        raise NotImplementedError("Predictive search not supported for this provider")