# src/ecommerce_toolkit/toolkit.py
from typing import Dict, List
from .config import StoreConfig
from .providers.shopify import ShopifyProvider
from .providers.woocommerce import WooCommerceProvider

class EcommerceToolkit:
    _instance = None
    
    def __new__(cls):
        if cls._instance is None:
            cls._instance = super(EcommerceToolkit, cls).__new__(cls)
            cls._instance._initialize()
        return cls._instance
    
    def _initialize(self):
        """Initialize the toolkit with the appropriate provider"""
        config = StoreConfig()
        
        if config.store_type == "shopify":
            if not config.shopify_token:
                raise ValueError("SHOPIFY_ACCESS_TOKEN environment variable is required for Shopify stores")
            self.provider = ShopifyProvider(config.store_url, config.shopify_token)
            
        elif config.store_type == "woocommerce":
            if not (config.woo_key and config.woo_secret):
                raise ValueError("WOO_CONSUMER_KEY and WOO_CONSUMER_SECRET environment variables are required for WooCommerce stores")
            self.provider = WooCommerceProvider(config.store_url, config.woo_key, config.woo_secret)
            
        else:
            raise ValueError(f"Unsupported store type: {config.store_type}")
    
    def list_all_products(self) -> List[Dict]:
        """Get all products from the store"""
        products = self.provider.get_products()
        return [vars(p) for p in products]
    
    def get_product_details(self, product_id: str) -> Dict:
        """Get details for a specific product"""
        product = self.provider.get_product(product_id)
        return vars(product)
    
    def search_store(self, query: str) -> List[Dict]:
        """Search for products in the store"""
        products = self.provider.search_products(query)
        return [vars(p) for p in products]